@@ -105,6 +105,7 @@ using clang::TemplateArgumentLoc;
 using clang::TemplateDecl;
 using clang::TemplateName;
 using clang::TemplateParameterList;
+using clang::TemplateSpecializationKind;
 using clang::TemplateSpecializationType;
 using clang::TranslationUnitDecl;
 using clang::Type;
@@ -120,7 +121,6 @@ using llvm::ArrayRef;
 using llvm::PointerUnion;
 using llvm::cast;
 using llvm::dyn_cast;
-using llvm::dyn_cast_or_null;
 using llvm::errs;
 using llvm::isa;
 using llvm::raw_string_ostream;
@@ -156,6 +156,13 @@ void DumpASTNode(llvm::raw_ostream& ostream, const ASTNode* node) {
   }
 }
 
+TemplateSpecializationKind GetTemplateSpecializationKind(const Decl* decl) {
+  if (const auto* record = dyn_cast<CXXRecordDecl>(decl)) {
+    return record->getTemplateSpecializationKind();
+  }
+  return clang::TSK_Undeclared;
+}
+
 }  // anonymous namespace
 
 //------------------------------------------------------------
@@ -618,7 +625,7 @@ const RecordDecl* GetDefinitionForClass(const Decl* decl) {
   const RecordDecl* as_record = DynCastFrom(decl);
   const ClassTemplateDecl* as_tpl = DynCastFrom(decl);
   if (as_tpl) {  // Convert the template to its underlying class defn.
-    as_record = dyn_cast_or_null<RecordDecl>(as_tpl->getTemplatedDecl());
+    as_record = DynCastFrom(as_tpl->getTemplatedDecl());
   }
   if (as_record) {
     if (const RecordDecl* record_dfn = as_record->getDefinition()) {
@@ -943,12 +950,20 @@ bool IsFriendDecl(const Decl* decl) {
   return decl->getFriendObjectKind() != Decl::FOK_None;
 }
 
+bool IsExplicitInstantiation(const clang::Decl* decl) {
+  TemplateSpecializationKind kind = GetTemplateSpecializationKind(decl);
+  return kind == clang::TSK_ExplicitInstantiationDeclaration ||
+         kind == clang::TSK_ExplicitInstantiationDefinition;
+}
+
 bool IsForwardDecl(const NamedDecl* decl) {
-  if (const auto* record_decl = dyn_cast<RecordDecl>(decl)) {
+  if (const auto* record_decl = dyn_cast<CXXRecordDecl>(decl)) {
+
     return (!record_decl->getName().empty() &&
             !record_decl->isCompleteDefinition() &&
             !record_decl->isEmbeddedInDeclarator() &&
-            !IsFriendDecl(record_decl));
+            !IsFriendDecl(record_decl) &&
+            !IsExplicitInstantiation(record_decl));
   }
 
   return false;
