@@ -90,7 +90,7 @@ const IncludeMapEntry libc_symbol_map[] = {
   // equivalents.
   // In each case, I ordered them so <sys/types.h> was first, if it was
   // an option for this type.  That's the preferred #include all else
-  // equal.  The visibility on the symbol-name is ignored; by convension
+  // equal.  The visibility on the symbol-name is ignored; by convention
   // we always set it to kPrivate.
   { "blksize_t", kPrivate, "<sys/types.h>", kPublic },
   { "blkcnt_t", kPrivate, "<sys/stat.h>", kPublic },
@@ -179,6 +179,7 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "size_t", kPrivate, "<stdlib.h>", kPublic },
   { "size_t", kPrivate, "<string.h>", kPublic },
   { "size_t", kPrivate, "<time.h>", kPublic },
+  { "size_t", kPrivate, "<uchar.h>", kPublic },
   { "size_t", kPrivate, "<wchar.h>", kPublic },
   // Macros that can be defined in more than one file, don't have the
   // same __foo_defined guard that other types do, so the grep above
@@ -548,80 +549,200 @@ const char* stdlib_cpp_public_headers[] = {
 
 // Private -> public include mappings for GNU libstdc++
 const IncludeMapEntry libstdcpp_include_map[] = {
-  // ( cd /usr/crosstool/v12/gcc-4.3.1-glibc-2.3.6-grte/x86_64-unknown-linux-gnu/x86_64-unknown-linux-gnu/include/c++/4.3.1 && grep '^ *# *include' {ext/,tr1/,}* | perl -nle 'm/^([^:]+).*<([^>]+)>/ && print qq@    { "<$2>", kPrivate, "<$1>", kPublic },@' | grep -e bits/ -e tr1_impl/ | sort -u)
-  // I removed a lot of 'meaningless' dependencies -- for instance,
-  // <functional> #includes <bits/stringfwd.h>, but if someone is
-  // using strings, <functional> isn't enough to satisfy iwyu.
-  // We may need to add other dirs in future versions of gcc.
+  // cd /usr/include/c++/8 && grep -r headername | perl -nle 'm/^([^:]+).*@headername\{([^,]*)\}/ && print qq@  { "<$1>", kPrivate, "<$2>", kPublic },@' | sort -u
+  { "<backward/auto_ptr.h>", kPrivate, "<memory>", kPublic },
+  { "<backward/backward_warning.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<backward/binders.h>", kPrivate, "<functional>", kPublic },
   { "<bits/algorithmfwd.h>", kPrivate, "<algorithm>", kPublic },
+  { "<bits/allocated_ptr.h>", kPrivate, "<memory>", kPublic },
   { "<bits/allocator.h>", kPrivate, "<memory>", kPublic },
-  { "<bits/atomic_word.h>", kPrivate, "<ext/atomicity.h>", kPublic },
-  { "<bits/basic_file.h>", kPrivate, "<fstream>", kPublic },
+  { "<bits/alloc_traits.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/atomic_base.h>", kPrivate, "<atomic>", kPublic },
+  { "<bits/atomic_lockfree_defines.h>", kPrivate, "<atomic>", kPublic },
   { "<bits/basic_ios.h>", kPrivate, "<ios>", kPublic },
+  { "<bits/basic_ios.tcc>", kPrivate, "<ios>", kPublic },
   { "<bits/basic_string.h>", kPrivate, "<string>", kPublic },
   { "<bits/basic_string.tcc>", kPrivate, "<string>", kPublic },
-  { "<bits/boost_sp_shared_count.h>", kPrivate, "<memory>", kPublic },
-  { "<bits/c++io.h>", kPrivate, "<ext/stdio_sync_filebuf.h>", kPublic },
-  { "<bits/c++config.h>", kPrivate, "<cstddef>", kPublic },
+  { "<bits/boost_concept_check.h>", kPrivate, "<iterator>", kPublic },
+  { "<bits/c++0x_warning.h>", kPrivate, "<iosfwd>", kPublic },
   { "<bits/char_traits.h>", kPrivate, "<string>", kPublic },
-  { "<bits/cmath.tcc>", kPrivate, "<cmath>", kPublic },
-  { "<bits/codecvt.h>", kPrivate, "<fstream>", kPublic },
-  { "<bits/cxxabi_tweaks.h>", kPrivate, "<cxxabi.h>", kPublic },
+  { "<bits/codecvt.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/concept_check.h>", kPrivate, "<iterator>", kPublic },
+  { "<bits/cpp_type_traits.h>", kPrivate, "<ext/type_traits>", kPublic },
+  { "<bits/cxxabi_forced.h>", kPrivate, "<cxxabi.h>", kPublic },
   { "<bits/deque.tcc>", kPrivate, "<deque>", kPublic },
+  { "<bits/exception_defines.h>", kPrivate, "<exception>", kPublic },
+  { "<bits/exception_ptr.h>", kPrivate, "<exception>", kPublic },
+  { "<bits/forward_list.h>", kPrivate, "<forward_list>", kPublic },
+  { "<bits/forward_list.tcc>", kPrivate, "<forward_list>", kPublic },
+  { "<bits/fs_dir.h>", kPrivate, "<filesystem>", kPublic },
+  { "<bits/fs_fwd.h>", kPrivate, "<filesystem>", kPublic },
+  { "<bits/fs_ops.h>", kPrivate, "<filesystem>", kPublic },
+  { "<bits/fs_path.h>", kPrivate, "<filesystem>", kPublic },
   { "<bits/fstream.tcc>", kPrivate, "<fstream>", kPublic },
-  { "<bits/functional_hash.h>", kPrivate, "<unordered_map>", kPublic },
-  { "<bits/gslice.h>", kPrivate, "<valarray>", kPublic },
+  { "<bits/functexcept.h>", kPrivate, "<exception>", kPublic },
+  { "<bits/functional_hash.h>", kPrivate, "<functional>", kPublic },
   { "<bits/gslice_array.h>", kPrivate, "<valarray>", kPublic },
-  { "<bits/hashtable.h>", kPrivate, "<unordered_map>", kPublic },
-  { "<bits/hashtable.h>", kPrivate, "<unordered_set>", kPublic },
+  { "<bits/gslice.h>", kPrivate, "<valarray>", kPublic },
+  { "<bits/hash_bytes.h>", kPrivate, "<functional>", kPublic },
   { "<bits/indirect_array.h>", kPrivate, "<valarray>", kPublic },
-  { "<bits/ios_base.h>", kPrivate, "<iostream>", kPublic },
+  { "<bits/invoke.h>", kPrivate, "<functional>", kPublic },
   { "<bits/ios_base.h>", kPrivate, "<ios>", kPublic },
-  { "<bits/ios_base.h>", kPrivate, "<iomanip>", kPublic },
+  { "<bits/istream.tcc>", kPrivate, "<istream>", kPublic },
+  { "<bits/list.tcc>", kPrivate, "<list>", kPublic },
   { "<bits/locale_classes.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/locale_classes.tcc>", kPrivate, "<locale>", kPublic },
+  { "<bits/locale_conv.h>", kPrivate, "<locale>", kPublic },
   { "<bits/locale_facets.h>", kPrivate, "<locale>", kPublic },
   { "<bits/locale_facets_nonio.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/locale_facets_nonio.tcc>", kPrivate, "<locale>", kPublic },
+  { "<bits/locale_facets.tcc>", kPrivate, "<locale>", kPublic },
   { "<bits/localefwd.h>", kPrivate, "<locale>", kPublic },
   { "<bits/mask_array.h>", kPrivate, "<valarray>", kPublic },
-  { "<bits/ostream.tcc>", kPrivate, "<ostream>", kPublic },
+  { "<bits/memoryfwd.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/move.h>", kPrivate, "<utility>", kPublic },
+  { "<bits/nested_exception.h>", kPrivate, "<exception>", kPublic },
   { "<bits/ostream_insert.h>", kPrivate, "<ostream>", kPublic },
-  { "<bits/postypes.h>", kPrivate, "<iostream>", kPublic },
+  { "<bits/ostream.tcc>", kPrivate, "<ostream>", kPublic },
+  { "<bits/parse_numbers.h>", kPrivate, "<chrono>", kPublic },
+  { "<bits/postypes.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<bits/predefined_ops.h>", kPrivate, "<algorithm>", kPublic },
+  { "<bits/ptr_traits.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/quoted_string.h>", kPrivate, "<iomanip>", kPublic },
+  { "<bits/random.h>", kPrivate, "<random>", kPublic },
+  { "<bits/random.tcc>", kPrivate, "<random>", kPublic },
+  { "<bits/range_access.h>", kPrivate, "<iterator>", kPublic },
+  { "<bits/refwrap.h>", kPrivate, "<functional>", kPublic },
+  { "<bits/regex_automaton.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_automaton.tcc>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_compiler.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_compiler.tcc>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_constants.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_error.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_executor.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_executor.tcc>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_scanner.h>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex_scanner.tcc>", kPrivate, "<regex>", kPublic },
+  { "<bits/regex.tcc>", kPrivate, "<regex>", kPublic },
+  { "<bits/shared_ptr_atomic.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/shared_ptr_base.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/shared_ptr.h>", kPrivate, "<memory>", kPublic },
   { "<bits/slice_array.h>", kPrivate, "<valarray>", kPublic },
-  { "<bits/stl_algo.h>", kPrivate, "<algorithm>", kPublic },
+  { "<bits/specfun.h>", kPrivate, "<cmath>", kPublic },
+  { "<bits/sstream.tcc>", kPrivate, "<sstream>", kPublic },
+  { "<bits/std_function.h>", kPrivate, "<functional>", kPublic },
+  { "<bits/std_mutex.h>", kPrivate, "<mutex>", kPublic },
   { "<bits/stl_algobase.h>", kPrivate, "<algorithm>", kPublic },
+  { "<bits/stl_algo.h>", kPrivate, "<algorithm>", kPublic },
   { "<bits/stl_bvector.h>", kPrivate, "<vector>", kPublic },
   { "<bits/stl_construct.h>", kPrivate, "<memory>", kPublic },
   { "<bits/stl_deque.h>", kPrivate, "<deque>", kPublic },
   { "<bits/stl_function.h>", kPrivate, "<functional>", kPublic },
   { "<bits/stl_heap.h>", kPrivate, "<queue>", kPublic },
-  { "<bits/stl_iterator.h>", kPrivate, "<iterator>", kPublic },
   { "<bits/stl_iterator_base_funcs.h>", kPrivate, "<iterator>", kPublic },
   { "<bits/stl_iterator_base_types.h>", kPrivate, "<iterator>", kPublic },
+  { "<bits/stl_iterator.h>", kPrivate, "<iterator>", kPublic },
   { "<bits/stl_list.h>", kPrivate, "<list>", kPublic },
   { "<bits/stl_map.h>", kPrivate, "<map>", kPublic },
   { "<bits/stl_multimap.h>", kPrivate, "<map>", kPublic },
   { "<bits/stl_multiset.h>", kPrivate, "<set>", kPublic },
   { "<bits/stl_numeric.h>", kPrivate, "<numeric>", kPublic },
   { "<bits/stl_pair.h>", kPrivate, "<utility>", kPublic },
-  { "<bits/stl_pair.h>", kPrivate, "<tr1/utility>", kPublic },
   { "<bits/stl_queue.h>", kPrivate, "<queue>", kPublic },
   { "<bits/stl_raw_storage_iter.h>", kPrivate, "<memory>", kPublic },
   { "<bits/stl_relops.h>", kPrivate, "<utility>", kPublic },
   { "<bits/stl_set.h>", kPrivate, "<set>", kPublic },
   { "<bits/stl_stack.h>", kPrivate, "<stack>", kPublic },
   { "<bits/stl_tempbuf.h>", kPrivate, "<memory>", kPublic },
-  { "<bits/stl_tree.h>", kPrivate, "<map>", kPublic },
-  { "<bits/stl_tree.h>", kPrivate, "<set>", kPublic },
   { "<bits/stl_uninitialized.h>", kPrivate, "<memory>", kPublic },
   { "<bits/stl_vector.h>", kPrivate, "<vector>", kPublic },
-  { "<bits/stream_iterator.h>", kPrivate, "<iterator>", kPublic },
-  { "<bits/streambuf.tcc>", kPrivate, "<streambuf>", kPublic },
   { "<bits/streambuf_iterator.h>", kPrivate, "<iterator>", kPublic },
+  { "<bits/streambuf.tcc>", kPrivate, "<streambuf>", kPublic },
+  { "<bits/stream_iterator.h>", kPrivate, "<iterator>", kPublic },
   { "<bits/stringfwd.h>", kPrivate, "<string>", kPublic },
+  { "<bits/string_view.tcc>", kPrivate, "<string_view>", kPublic },
+  { "<bits/uniform_int_dist.h>", kPrivate, "<random>", kPublic },
+  { "<bits/unique_ptr.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/unordered_map.h>", kPrivate, "<unordered_map>", kPublic },
+  { "<bits/unordered_set.h>", kPrivate, "<unordered_set>", kPublic },
   { "<bits/valarray_after.h>", kPrivate, "<valarray>", kPublic },
   { "<bits/valarray_array.h>", kPrivate, "<valarray>", kPublic },
+  { "<bits/valarray_array.tcc>", kPrivate, "<valarray>", kPublic },
   { "<bits/valarray_before.h>", kPrivate, "<valarray>", kPublic },
   { "<bits/vector.tcc>", kPrivate, "<vector>", kPublic },
+  { "<decimal/decimal.h>", kPrivate, "<decimal>", kPublic },
+  { "<experimental/bits/fs_dir.h>", kPrivate, "<experimental/filesystem>", kPublic },
+  { "<experimental/bits/fs_fwd.h>", kPrivate, "<experimental/filesystem>", kPublic },
+  { "<experimental/bits/fs_ops.h>", kPrivate, "<experimental/filesystem>", kPublic },
+  { "<experimental/bits/fs_path.h>", kPrivate, "<experimental/filesystem>", kPublic },
+  { "<experimental/bits/shared_ptr.h>", kPrivate, "<experimental/memory>", kPublic },
+  { "<experimental/bits/string_view.tcc>", kPrivate, "<experimental/string_view>", kPublic },
+  { "<ext/cast.h>", kPrivate, "<ext/pointer.h>", kPublic },
+  { "<ext/random.tcc>", kPrivate, "<ext/random>", kPublic },
+  { "<ext/rc_string_base.h>", kPrivate, "<ext/vstring.h>", kPublic },
+  { "<ext/ropeimpl.h>", kPrivate, "<ext/rope>", kPublic },
+  { "<ext/sso_string_base.h>", kPrivate, "<ext/vstring.h>", kPublic },
+  { "<ext/vstring_fwd.h>", kPrivate, "<ext/vstring.h>", kPublic },
+  { "<ext/vstring.tcc>", kPrivate, "<ext/vstring.h>", kPublic },
+  { "<ext/vstring_util.h>", kPrivate, "<ext/vstring.h>", kPublic },
+  { "<tr1/bessel_function.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/beta_function.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/ell_integral.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/exp_integral.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/functional_hash.h>", kPrivate, "<tr1/functional>", kPublic },
+  { "<tr1/gamma.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/hypergeometric.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/legendre_function.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/modified_bessel_func.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/poly_hermite.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/poly_laguerre.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/random.h>", kPrivate, "<tr1/random>", kPublic },
+  { "<tr1/random.tcc>", kPrivate, "<tr1/random>", kPublic },
+  { "<tr1/riemann_zeta.tcc>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/shared_ptr.h>", kPrivate, "<tr1/memory>", kPublic },
+  { "<tr1/special_function_util.h>", kPrivate, "<tr1/cmath>", kPublic },
+  { "<tr1/unordered_map.h>", kPrivate, "<tr1/unordered_map>", kPublic },
+  { "<tr1/unordered_set.h>", kPrivate, "<tr1/unordered_set>", kPublic },
+  { "<tr2/dynamic_bitset.tcc>", kPrivate, "<tr2/dynamic_bitset>", kPublic },
+  // cd /usr/include/x86_64-linux-gnu/c++/8 && grep -r headername | perl -nle 'm/^([^:]+).*@headername\{([^,]*)\}/ && print qq@  { "<$1>", kPrivate, "<$2>", kPublic },@' | sort -u
+  { "<bits/basic_file.h>", kPrivate, "<ios>", kPublic },
+  { "<bits/c++allocator.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/c++config.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<bits/c++io.h>", kPrivate, "<ios>", kPublic },
+  { "<bits/c++locale.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/cpu_defines.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<bits/ctype_base.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/ctype_inline.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/cxxabi_tweaks.h>", kPrivate, "<cxxabi.h>", kPublic },
+  { "<bits/error_constants.h>", kPrivate, "<system_error>", kPublic },
+  { "<bits/messages_members.h>", kPrivate, "<locale>", kPublic },
+  { "<bits/opt_random.h>", kPrivate, "<random>", kPublic },
+  { "<bits/os_defines.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<bits/time_members.h>", kPrivate, "<locale>", kPublic },
+  { "<ext/opt_random.h>", kPrivate, "<ext/random>", kPublic },
+  // ( cd /usr/crosstool/v12/gcc-4.3.1-glibc-2.3.6-grte/x86_64-unknown-linux-gnu/x86_64-unknown-linux-gnu/include/c++/4.3.1 && grep '^ *# *include' {ext/,tr1/,}* | perl -nle 'm/^([^:]+).*<([^>]+)>/ && print qq@    { "<$2>", kPrivate, "<$1>", kPublic },@' | grep -e bits/ -e tr1_impl/ | sort -u)
+  // I removed a lot of 'meaningless' dependencies -- for instance,
+  // <functional> #includes <bits/stringfwd.h>, but if someone is
+  // using strings, <functional> isn't enough to satisfy iwyu.
+  // We may need to add other dirs in future versions of gcc.
+  { "<bits/atomic_word.h>", kPrivate, "<ext/atomicity.h>", kPublic },
+  { "<bits/basic_file.h>", kPrivate, "<fstream>", kPublic },
+  { "<bits/boost_sp_shared_count.h>", kPrivate, "<memory>", kPublic },
+  { "<bits/c++io.h>", kPrivate, "<ext/stdio_sync_filebuf.h>", kPublic },
+  { "<bits/c++config.h>", kPrivate, "<cstddef>", kPublic },
+  { "<bits/cmath.tcc>", kPrivate, "<cmath>", kPublic },
+  { "<bits/codecvt.h>", kPrivate, "<fstream>", kPublic },
+  { "<bits/cxxabi_tweaks.h>", kPrivate, "<cxxabi.h>", kPublic },
+  { "<bits/functional_hash.h>", kPrivate, "<unordered_map>", kPublic },
+  { "<bits/hashtable.h>", kPrivate, "<unordered_map>", kPublic },
+  { "<bits/hashtable.h>", kPrivate, "<unordered_set>", kPublic },
+  { "<bits/ios_base.h>", kPrivate, "<iostream>", kPublic },
+  { "<bits/ios_base.h>", kPrivate, "<iomanip>", kPublic },
+  { "<bits/postypes.h>", kPrivate, "<iostream>", kPublic },
+  { "<bits/stl_pair.h>", kPrivate, "<tr1/utility>", kPublic },
+  { "<bits/stl_tree.h>", kPrivate, "<map>", kPublic },
+  { "<bits/stl_tree.h>", kPrivate, "<set>", kPublic },
   { "<tr1_impl/array>", kPrivate, "<array>", kPublic },
   { "<tr1_impl/array>", kPrivate, "<tr1/array>", kPublic },
   { "<tr1_impl/boost_shared_ptr.h>", kPrivate, "<memory>", kPublic },
@@ -662,12 +783,10 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<tr1_impl/unordered_set>", kPrivate, "<unordered_set>", kPublic },
   { "<tr1_impl/utility>", kPrivate, "<tr1/utility>", kPublic },
   { "<tr1_impl/utility>", kPrivate, "<utility>", kPublic },
-  { "<bits/move.h>", kPrivate, "<utility>", kPublic },
   // Hash and hashtable-based containers.
   { "<tr1_impl/functional_hash.h>", kPrivate, "<tr1/functional>", kPublic },
   { "<tr1_impl/functional_hash.h>", kPrivate, "<tr1/unordered_map>", kPublic },
   { "<tr1_impl/functional_hash.h>", kPrivate, "<tr1/unordered_set>", kPublic },
-  { "<tr1/functional_hash.h>", kPrivate, "<tr1/functional>", kPublic },
   { "<tr1/functional_hash.h>", kPrivate, "<tr1/unordered_map>", kPublic },
   { "<tr1/functional_hash.h>", kPrivate, "<tr1/unordered_set>", kPublic },
   { "<tr1_impl/hashtable>", kPrivate, "<tr1/unordered_map>", kPublic },
@@ -677,65 +796,23 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   // All .tcc files are gcc internal-include files.  We get them from
   // ( cd /usr/crosstool/v12/gcc-4.3.1-glibc-2.3.6-grte/x86_64-unknown-linux-gnu/x86_64-unknown-linux-gnu/include/c++/4.3.1 && grep -R '^ *# *include.*tcc' * | perl -nle 'm/^([^:]+).*[<"]([^>"]+)[>"]/ && print qq@    { "<$2>", kPrivate, "<$1>", kPublic },@' | sort )
   // I had to manually edit some of the entries to say the map-to is private.
-  { "<bits/basic_ios.tcc>", kPrivate, "<bits/basic_ios.h>", kPrivate },
-  { "<bits/basic_string.tcc>", kPrivate, "<string>", kPublic },
   { "<bits/cmath.tcc>", kPrivate, "<cmath>", kPublic },
-  { "<bits/deque.tcc>", kPrivate, "<deque>", kPublic },
-  { "<bits/fstream.tcc>", kPrivate, "<fstream>", kPublic },
-  { "<bits/istream.tcc>", kPrivate, "<istream>", kPublic },
-  { "<bits/list.tcc>", kPrivate, "<list>", kPublic },
-  { "<bits/locale_classes.tcc>", kPrivate, 
-    "<bits/locale_classes.h>", kPrivate },
-  { "<bits/locale_facets.tcc>", kPrivate, "<bits/locale_facets.h>", kPrivate },
-  { "<bits/locale_facets_nonio.tcc>", kPrivate,
-    "<bits/locale_facets_nonio.h>", kPrivate },
-  { "<bits/ostream.tcc>", kPrivate, "<ostream>", kPublic },
-  { "<bits/sstream.tcc>", kPrivate, "<sstream>", kPublic },
-  { "<bits/streambuf.tcc>", kPrivate, "<streambuf>", kPublic },
-  { "<bits/valarray_array.tcc>", kPrivate, 
-    "<bits/valarray_array.h>", kPrivate },
-  { "<bits/vector.tcc>", kPrivate, "<vector>", kPublic },
   { "<debug/safe_iterator.tcc>", kPrivate, "<debug/safe_iterator.h>", kPublic },
-  { "<tr1/bessel_function.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/beta_function.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/ell_integral.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/exp_integral.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/gamma.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/hypergeometric.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/legendre_function.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/modified_bessel_func.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/poly_hermite.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/poly_laguerre.tcc>", kPrivate, "<tr1/cmath>", kPublic },
-  { "<tr1/riemann_zeta.tcc>", kPrivate, "<tr1/cmath>", kPublic },
   { "<tr1_impl/random.tcc>", kPrivate, "<tr1_impl/random>", kPrivate },
   // Some bits->bits #includes: A few files in bits re-export
   // symbols from other files in bits.
   // ( cd /usr/crosstool/v12/gcc-4.3.1-glibc-2.3.6-grte/x86_64-unknown-linux-gnu/x86_64-unknown-linux-gnu/include/c++/4.3.1 && grep '^ *# *include.*bits/' bits/* | perl -nle 'm/^([^:]+).*<([^>]+)>/ && print qq@  { "<$2>", kPrivate, "<$1>", kPrivate },@' | grep bits/ | sort -u)
   // and carefully picked reasonable-looking results (algorithm
   // *uses* pair but doesn't *re-export* pair, for instance).
-  { "<bits/boost_concept_check.h>", kPrivate,
-    "<bits/concept_check.h>", kPrivate },
   { "<bits/c++allocator.h>", kPrivate, "<bits/allocator.h>", kPrivate },
-  { "<bits/codecvt.h>", kPrivate, "<bits/locale_facets_nonio.h>", kPrivate },
   { "<bits/ctype_base.h>", kPrivate, "<bits/locale_facets.h>", kPrivate },
   { "<bits/ctype_inline.h>", kPrivate, "<bits/locale_facets.h>", kPrivate },
-  { "<bits/functexcept.h>", kPrivate, "<bits/stl_algobase.h>", kPrivate },
-  { "<bits/locale_classes.h>", kPrivate, "<bits/basic_ios.h>", kPrivate },
-  { "<bits/locale_facets.h>", kPrivate, "<bits/basic_ios.h>", kPrivate },
   { "<bits/messages_members.h>", kPrivate,
     "<bits/locale_facets_nonio.h>", kPrivate },
-  { "<bits/postypes.h>", kPrivate, "<bits/char_traits.h>", kPrivate },
-  { "<bits/slice_array.h>", kPrivate, "<bits/valarray_before.h>", kPrivate },
-  { "<bits/stl_construct.h>", kPrivate, "<bits/stl_tempbuf.h>", kPrivate },
   { "<bits/stl_move.h>", kPrivate, "<bits/stl_algobase.h>", kPrivate },
-  { "<bits/stl_uninitialized.h>", kPrivate, "<bits/stl_tempbuf.h>", kPrivate },
-  { "<bits/stl_vector.h>", kPrivate, "<bits/stl_bvector.h>", kPrivate },
-  { "<bits/streambuf_iterator.h>", kPrivate, "<bits/basic_ios.h>", kPrivate },
   // I don't think we want to be having people move to 'backward/'
   // yet.  (These hold deprecated STL classes that we still use
   // actively.)  These are the ones that turned up in an analysis of
-  { "<backward/auto_ptr.h>", kPrivate, "<memory>", kPublic },
-  { "<backward/binders.h>", kPrivate, "<functional>", kPublic },
   { "<backward/hash_fun.h>", kPrivate, "<hash_map>", kPublic },
   { "<backward/hash_fun.h>", kPrivate, "<hash_set>", kPublic },
   { "<backward/hashtable.h>", kPrivate, "<hash_map>", kPublic },
@@ -771,7 +848,6 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<streambuf>", kPublic, "<ios>", kPublic },
   // The location of exception_defines.h varies by GCC version.  It should
   // never be included directly.
-  { "<bits/exception_defines.h>", kPrivate, "<exception>", kPublic },
   { "<exception_defines.h>", kPrivate, "<exception>", kPublic },
 };
 
