@@ -237,12 +237,12 @@ string GetShortNameAsString(const clang::NamedDecl* named_decl) {
 
 // Holds information about a single full or fwd-decl use of a symbol.
 OneUse::OneUse(const NamedDecl* decl, SourceLocation use_loc,
-               OneUse::UseKind use_kind, UseFlags flags,
-               const char* comment)
+               SourceLocation decl_loc, OneUse::UseKind use_kind,
+               UseFlags flags, const char* comment)
     : symbol_name_(internal::GetQualifiedNameAsString(decl)),
       short_symbol_name_(internal::GetShortNameAsString(decl)),
       decl_(decl),
-      decl_loc_(GetInstantiationLoc(GetLocation(decl))),
+      decl_loc_(GetInstantiationLoc(decl_loc)),
       decl_file_(GetFileEntry(decl_loc_)),
       decl_filepath_(GetFilePath(decl_file_)),
       use_loc_(use_loc),
@@ -577,15 +577,23 @@ void IwyuFileInfo::ReportFullSymbolUse(SourceLocation use_loc,
                                        UseFlags flags,
                                        const char* comment) {
   if (decl) {
-    // Since we need the full symbol, we need the decl's definition-site.
-    // But only if we're not defining the function, in which case we want to use
-    // all its preceding declarations, and not try to canonicalize.
-    if (!(flags & UF_FunctionDfn)) {
-      decl = GetDefinitionAsWritten(decl);
+    const NamedDecl* report_decl;
+    SourceLocation report_decl_loc;
+
+    if ((flags & (UF_FunctionDfn | UF_ExplicitInstantiation)) == 0) {
+      // Since we need the full symbol, we need the decl's definition-site too.
+      // Also, by default we canonicalize the location, using GetLocation.
+      report_decl = GetDefinitionAsWritten(decl);
+      report_decl_loc = GetLocation(report_decl);
+    } else {
+      // However, if we're defining the function or we are targeting an explicit
+      // instantiation, we want to use it as-is and not try to canonicalize at all.
+      report_decl = decl;
+      report_decl_loc = decl->getLocation();
     }
 
-    symbol_uses_.push_back(OneUse(decl, use_loc, OneUse::kFullUse,
-                                  flags, comment));
+    symbol_uses_.push_back(OneUse(report_decl, use_loc, report_decl_loc,
+                                  OneUse::kFullUse, flags, comment));
     LogSymbolUse("Marked full-info use of decl", symbol_uses_.back());
   }
 }
@@ -630,8 +638,8 @@ void IwyuFileInfo::ReportForwardDeclareUse(SourceLocation use_loc,
   // combines friend decls with true forward-declare decls.  If that
   // happened here, replace the friend with a real fwd decl.
   decl = GetNonfriendClassRedecl(decl);
-  symbol_uses_.push_back(OneUse(decl, use_loc, OneUse::kForwardDeclareUse,
-                                flags, comment));
+  symbol_uses_.push_back(OneUse(decl, use_loc, GetLocation(decl),
+                                OneUse::kForwardDeclareUse, flags, comment));
   LogSymbolUse("Marked fwd-decl use of decl", symbol_uses_.back());
 }
 
@@ -1120,16 +1128,27 @@ void ProcessFullUse(OneUse* use,
     }
   }
 
-  // (B3) Discard symbol uses for builtin symbols, including new/delete.
-  // TODO(csilvers): we could use getBuiltinID(), but it returns
-  // non-zero for things like malloc.  Figure out how to use it.
-  if (const FunctionDecl* fn_decl = DynCastFrom(use->decl())) {
-    if (StartsWith(use->symbol_name(), "__builtin_")) {
+  // (B3) Discard symbol uses for builtin symbols, including new/delete and
+  // template builtins.
+  if (isa<clang::BuiltinTemplateDecl>(use->decl())) {
+    VERRS(6) << "Ignoring use of " << use->symbol_name()
+             << " (" << use->PrintableUseLoc() << "): built-in template\n";
+    use->set_ignore_use();
+    return;
+  }
+  // A compiler builtin without a predefined header file (e.g. __builtin_..)
+  if (const clang::IdentifierInfo* iden = use->decl()->getIdentifier()) {
+    if (iden->getBuiltinID() != 0 &&
+        !clang::Builtin::Context::isBuiltinFunc(use->symbol_name().c_str())) {
       VERRS(6) << "Ignoring use of " << use->symbol_name()
                << " (" << use->PrintableUseLoc() << "): built-in function\n";
       use->set_ignore_use();
       return;
     }
+  }
+  // Special case for operators new/delete: Only treated as built-in if they
+  // are the default, non-placement versions.
+  if (const FunctionDecl* fn_decl = DynCastFrom(use->decl())) {
     const string dfn_file = GetFilePath(fn_decl);
     if (IsDefaultNewOrDelete(fn_decl, ConvertToQuotedInclude(dfn_file))) {
       VERRS(6) << "Ignoring use of " << use->symbol_name()
@@ -1774,29 +1793,49 @@ OutputLine PrintableIncludeOrForwardDeclareLine(
     GetSymbolsSortedByFrequency(line.symbol_counts()));
 }
 
-typedef pair<int, string> LineSortKey;
+enum class LineSortOrdinal {
+  PrecompiledHeader,
+  AssociatedHeader,
+  AssociatedInlineDefinitions,
+  QuotedInclude,
+  CHeader,
+  CppHeader,
+  OtherHeader,
+  ForwardDeclaration
+};
 
-// The sort key of an include/forward-declare line is an (int, string)
-// pair.  The string is always the line itself.  The int is a category:
-// 0: PCH in code, 1: associated .h, 2: associated -inl.h, 3: C header,
-// 4: c++ header, 5: other header, 6: forward-declare.
+using LineSortKey = pair<LineSortOrdinal, string>;
+
+LineSortOrdinal GetLineSortOrdinal(const OneIncludeOrForwardDeclareLine& line,
+                                   const set<string>& associated_quoted_includes,
+                                   const IwyuFileInfo* file_info) {
+  if (!line.IsIncludeLine())
+    return LineSortOrdinal::ForwardDeclaration;
+  if (file_info && file_info->is_pch_in_code())
+    return LineSortOrdinal::PrecompiledHeader;
+
+  const std::string quoted_include = line.quoted_include();
+  if (ContainsKey(associated_quoted_includes, quoted_include)) {
+    if (EndsWith(quoted_include, "-inl.h\""))
+      return LineSortOrdinal::AssociatedInlineDefinitions;
+    return LineSortOrdinal::AssociatedHeader;
+  }
+
+  if (GlobalFlags().quoted_includes_first && EndsWith(quoted_include, "\""))
+    return LineSortOrdinal::QuotedInclude;
+  if (EndsWith(quoted_include, ".h>"))
+    return LineSortOrdinal::CHeader;
+  if (EndsWith(quoted_include, ">"))
+    return LineSortOrdinal::CppHeader;
+  return LineSortOrdinal::OtherHeader;
+}
+
+// The sort key of an include/forward-declare line is a (LineSortOrdinal, string)
+// pair.  The string is always the line itself.
 LineSortKey GetSortKey(const OneIncludeOrForwardDeclareLine& line,
                        const set<string>& associated_quoted_includes,
                        const IwyuFileInfo* file_info) {
-  if (!line.IsIncludeLine())
-    return LineSortKey(6, line.line());
-  if (file_info && file_info->is_pch_in_code())
-    return LineSortKey(0, line.line());
-  if (ContainsKey(associated_quoted_includes, line.quoted_include())) {
-    if (EndsWith(line.quoted_include(), "-inl.h\""))
-      return LineSortKey(2, line.line());
-    return LineSortKey(1, line.line());
-  }
-  if (EndsWith(line.quoted_include(), ".h>"))
-    return LineSortKey(3, line.line());
-  if (EndsWith(line.quoted_include(), ">"))
-    return LineSortKey(4, line.line());
-  return LineSortKey(5, line.line());
+  return LineSortKey(GetLineSortOrdinal(line, associated_quoted_includes, file_info), line.line());
 }
 
 // filename is "this" filename: the file being emitted.
